@@ -11,10 +11,8 @@ from matplotlib import pyplot as plt
 
 from argparse import ArgumentParser
 
-from .dataset import DataSet
-from .hdf5_save import load_dataset
-from . import output
-from .parse_input import parse_parameters
+from VoigtFit import container
+from VoigtFit import io
 
 
 warnings.filterwarnings("ignore", category=matplotlib.mplDeprecation)
@@ -74,16 +72,16 @@ def main():
         print("  I have created a blank template for you to get started: 'vfit.pars'.")
         print("  Please edit this file and run VoigtFit again with this file as input.")
         print("")
-        output.create_blank_input()
+        io.output.create_blank_input()
         return
 
-    parameters = parse_parameters(parfile)
+    parameters = io.parse_input.parse_parameters(parfile)
     print(" Reading Parameters from file: " + parfile)
 
     name = parameters['name']
     # -- Load DataSet if the file already exists
     if os.path.exists(name+'.hdf5') and not args.f:
-        dataset = load_dataset(name+'.hdf5')
+        dataset = io.hdf5_save.load_dataset(name+'.hdf5')
         if verbose:
             print("Loaded dataset: %s.hdf5" % name)
 
@@ -191,6 +189,7 @@ def main():
                         if np.abs(reg.velspan - velspan) < 0.1:
                             if verbose:
                                 print(" Detected difference in velocity span: %s" % ground_state)
+                            dataset.verbose = False
                             dataset.remove_fine_lines(ground_state)
                             new_fine_lines.append([ground_state, levels, velspan])
 
@@ -241,7 +240,7 @@ def main():
 
     else:
         # --- Create a new DataSet
-        dataset = DataSet(parameters['z_sys'], parameters['name'])
+        dataset = container.dataset.DataSet(parameters['z_sys'], parameters['name'])
 
         if 'velspan' in parameters.keys():
             dataset.velspan = parameters['velspan']
@@ -367,7 +366,7 @@ def main():
         for num in comps_to_del:
             dataset.delete_component(ion, num)
 
-            # Also remove component from therma_model
+            # Also remove component from thermal_model
             if ion in thermal_model.keys():
                 if num in thermal_model[ion]:
                     thermal_model[ion].remove(num)
@@ -558,7 +557,7 @@ def main():
 
     if len(thermal_model.keys()) > 0:
         # print Thermal Model Parameters
-        output.print_T_model_pars(dataset, thermal_model)
+        io.output.print_T_model_pars(dataset, thermal_model)
 
     # print metallicity
     logNHI = parameters['logNHI']
@@ -586,10 +585,10 @@ def main():
                 EW = dataset.equivalent_width_limit(line_tag, verbose=True, **limit_options)
                 if EW is not None:
                     EW_limits.append(EW)
-                    print(output.format_EW(EW))
+                    print(io.output.format_EW(EW))
         print("")
         # Save to file:
-        output.save_EW(EW_limits, filename+'.limits')
+        io.output.save_EW(EW_limits, filename+'.limits')
 
     # Output:
     if 'individual-regions' in parameters['output_pars']:
@@ -608,13 +607,13 @@ def main():
     else:
         rebin = 1
     dataset.plot_fit(filename=filename, rebin=rebin)
-    output.save_parameters_to_file(dataset, filename+'.fit')
+    io.output.save_parameters_to_file(dataset, filename+'.fit')
     if dataset.cheb_order >= 0:
-        output.save_cont_parameters_to_file(dataset, filename+'.cont')
-    output.save_fit_regions(dataset, filename+'.reg',
-                            individual=individual_regions)
+        io.output.save_cont_parameters_to_file(dataset, filename+'.cont')
+    io.output.save_fit_regions(dataset, filename+'.reg',
+                               individual=individual_regions)
     if individual_components:
-        output.save_individual_components(dataset, filename+'.components')
+        io.output.save_individual_components(dataset, filename+'.components')
     print(" - Done...\n")
     plt.show(block=True)
 
